/**
 * conceptERP Zarafa-Plugin
 *
 * Changed by: Maik Unruh mm-concept
 * Based on Z-Merge Archive Plugin by Sebastian Kummer <s.kummer@zarafa.com>
 *
 */
Pluginconcepterp.prototype = new Plugin;
Pluginconcepterp.prototype.constructor = Pluginconcepterp;
Pluginconcepterp.superclass = Plugin.prototype;

function Pluginconcepterp(){}

/**
 * init
 *
 * registers for events 
 */
Pluginconcepterp.prototype.init = function(){
    this.registerHook("client.module.maillistmodule.contextmenu.buildup");
    this.registerHook("client.module.maillistmodule.execute.before");
}

/**
 * execute
 *
 * is called when registered events are triggered 
 */
Pluginconcepterp.prototype.execute = function(eventID, data){
    switch(eventID){
        case "client.module.maillistmodule.contextmenu.buildup":
            this.addArchiveContextMenu(data);
            break;
        case "client.module.maillistmodule.execute.before":
            this.mailListModuleExecute(data);
            break;
    }
}

/**
 * Event: addArchiveContextMenu
 *
 * adds new entries to the contextmenu
 */
Pluginconcepterp.prototype.addArchiveContextMenu = function(data){
    var items = data["contextmenu"];

    if (window.concepterpprofiles) {
        items.push(webclient.menu.createMenuItem("seperator", ""));    

        for(var profilename in window.concepterpprofiles) {
            items.push(webclient.menu.createMenuItem("concepterp_"+profilename, window.concepterpprofiles[profilename]+"...", false, Pluginconcepterp.prototype.eventListContextArchiveEmail, false, false, {profile: profilename}));
        }
    }
    else alert(dgettext("plugin_concepterp", "Z-Merge Archive: invalid configuration"));
}

/**
 * Event: eventListContextArchiveEmail
 *
 * directly called (from maillistmodule) when the inserted events are triggered
 * contacts server to start archivation
 */
Pluginconcepterp.prototype.eventListContextArchiveEmail = function(moduleObject, element, event){
    // Hide menu
    element.parentNode.style.display = "none";
    
    var data = new Array()
    data["profile"] = element.data['profile'];
    data["store"] = moduleObject.storeid;
    data["parententryid"] = moduleObject.entryid;
    data["entryid"] = moduleObject.entryids[element.parentNode.elementid];
    webclient.xmlrequest.addData(this, "concepterpSendMail", data);

    // deselect selected message
    eventListCheckSelectedContextMessage(this);
}

/**
 * Event: mailListModuleExecute
 *
 * process incoming execute events for maillistmodule
 */
Pluginconcepterp.prototype.mailListModuleExecute = function(data) {
    var type = data["type"];
    var action = data["action"];

    switch(type){
        case "archiveResponse":
            this.archiveResponse(action);
            break;
    }
}

/**
 * Event: archiveResponse
 *
 * process responses from the 3rd party server
 */
Pluginconcepterp.prototype.archiveResponse = function(action) {
    var status = dhtml.getXMLValue(action, "status", "none");
    var message = dhtml.getXMLValue(action, "message", "none");
    var serverurl = dhtml.getXMLValue(action, "serverurl", "none");

    if (status == "ok") {
        var concepterpwindow = window.open(serverurl);
        concepterpwindow.focus();
    }
    else {
        alert(dgettext("plugin_concepterp", "An error occured while archiving")+":\n"+ ((message=="none")?dgettext("plugin_concepterp", 'unknown error'):message));
    }
}
